@@ -2,7 +2,6 @@ import logging
 import time
 import datetime
 import warnings
-import requests
 from functools import reduce
 from itertools import product
 from typing import Callable
@@ -79,18 +78,12 @@ class PostgreSQLUtils:
         """
 
         if self.account_name:
-            try:
-                credentials = get_credentials(
-                    platform='pg',
-                    account_name=self.account_name,
-                )
-                db_user = credentials['user_name']
-                db_password = credentials['password']
-            except Exception:
-                logging.error('Failed to get account credentials from minIO')
-                logging.info('Try using backup account')
-                db_user = 'y4a_sop_af_trino'
-                db_password = 'FJ!dlskjd0912lkjsd'
+            credentials = get_credentials(
+                platform='pg',
+                account_name=self.account_name,
+            )
+            db_user = credentials['user_name']
+            db_password = credentials['password']
         else:
             db_user = self.pg_account
             db_password = self.pg_password
@@ -1312,12 +1305,6 @@ class PostgreSQLUtils:
             db_pool_conn=db_pool_conn,
         )
 
-        self.auto_grant(
-            schema=schema,
-            list_tables=[table],
-            predefined_rules=True,
-        )
-
     def create_table_from_df(
         self,
         data: pd.DataFrame,
@@ -1333,18 +1320,12 @@ class PostgreSQLUtils:
         """
 
         if self.account_name:
-            try:
-                credentials = get_credentials(
-                    platform='pg',
-                    account_name=self.account_name,
-                )
-                db_user = credentials['user_name']
-                db_password = credentials['password']
-            except Exception:
-                logging.error('Failed to get account credentials from minIO')
-                logging.info('Try using backup account')
-                db_user = 'y4a_sop_af_trino'
-                db_password = 'FJ!dlskjd0912lkjsd'
+            credentials = get_credentials(
+                platform='pg',
+                account_name=self.account_name,
+            )
+            db_user = credentials['user_name']
+            db_password = credentials['password']
         else:
             db_user = self.pg_account
             db_password = self.pg_password
@@ -1361,12 +1342,6 @@ class PostgreSQLUtils:
             index=False,
         )
 
-        self.auto_grant(
-            schema=schema,
-            list_tables=[table],
-            predefined_rules=True,
-        )
-
     def generate_log_data_path(
         self,
         file_path: str,
@@ -1580,10 +1555,9 @@ class PostgreSQLUtils:
         self,
         schema: str,
         list_tables: list,
-        list_users: list = None,
+        list_users: list,
         privileges: list = ['SELECT'],
         all_privileges: bool = False,
-        predefined_rules: bool = False,
     ) -> None:
         """
         Grant table privileges to users in PostgreSQL
@@ -1591,72 +1565,67 @@ class PostgreSQLUtils:
         :param schema: schema containing the table to grant
         :param list_tables: list of tables name to grant
         :param list_users: list of users to grant access
-            defaults to None
-            if None, the table will be granted for
-            all the predefined users
         :param privileges: list of privileges to grant
             defaults to ['SELECT']
         :param all_privileges: whether to grant all privileges
             defaults to False
-        :param predefined_rules: whether to grant the table with
-            the predefined rules
-            defaults to False
         """
+        to_grant = list()
+        for user in list_users:
+            try:
+                to_grant.append(
+                    get_credentials(
+                        platform='pg',
+                        account_name=user,
+                    )['user_name']
+                )
+            except IndexError:
+                to_grant.append(user)
 
-        response = requests.get(
-            f"http://172.30.15.171:5431/v1/postgres/grant/{schema}"
-        ).json()
-
-        list_user_read = response["list_user_read"]
-        list_user_privileges = response["list_user_privileges"]
-
-        if predefined_rules:
-            for table, user in product(
-                list_tables,
-                list_user_read,
-            ):
-                table_grant = "GRANT SELECT ON "
-                table_grant += f"{schema}.{table} to {user}"
-
-                self.execute(table_grant)
-                logging.info(table_grant)
-
-            for table, user in product(
-                list_tables,
-                list_user_privileges,
-            ):
+        for table, user in product(
+            list_tables,
+            to_grant,
+        ):
+            if all_privileges:
                 table_grant = f"GRANT ALL PRIVILEGES ON {schema}.{table} "
                 table_grant += f"to {user}"
-
-                self.execute(table_grant)
-                logging.info(table_grant)
-        else:
-            if not list_users:
-                to_grant = list_user_read + list_user_privileges
             else:
-                to_grant = list()
-                for user in list_users:
-                    try:
-                        to_grant.append(
-                            get_credentials(
-                                platform='pg',
-                                account_name=user,
-                            )['user_name']
-                        )
-                    except IndexError:
-                        to_grant.append(user)
+                table_privileges = ', '.join(privileges)
+                table_grant = f"GRANT {table_privileges} ON "
+                table_grant += f"{schema}.{table} to {user}"
 
-            for table, user in product(
-                list_tables,
-                to_grant,
-            ):
-                if all_privileges:
-                    table_grant = f"GRANT ALL PRIVILEGES ON {schema}.{table} "
-                    table_grant += f"to {user}"
-                else:
-                    table_privileges = ', '.join(privileges)
-                    table_grant = f"GRANT {table_privileges} ON "
-                    table_grant += f"{schema}.{table} to {user}"
+            self.execute(table_grant)
+            logging.info(table_grant)
 
-                self.execute(table_grant)
-                logging.info(table_grant)
+    def sync_tmp2cdm(
+        self,
+        from_table: str,
+        to_table: str,
+    ) -> None:
+        conn = self.open_conn()
+
+        try:
+            cur = conn.cursor()
+
+            truncate_sql = f"TRUNCATE TABLE y4a_cdm.{to_table}"
+            cur.execute(truncate_sql)
+
+            insert_sql = f"""
+            INSERT INTO
+                y4a_cdm.{to_table}
+            SELECT
+                *
+            FROM
+                y4a_temp.{from_table}
+            """
+            cur.execute(insert_sql)
+
+            conn.commit()
+            cur.close()
+            self.close_conn(conn)
+            logging.info('Data synced')
+        except Exception as e:
+            conn.rollback()
+            cur.close()
+            self.close_conn(conn)
+            raise e
